@@ -10,7 +10,7 @@ import unicodedata
 import logging
 import gzip
 
-VERSION = "0.4.0"
+VERSION = "0.5.0"
 
 
 class Dat2Html:
@@ -281,7 +281,8 @@ class Dat2Html:
              .encode("cp932"), x.group(1), x.group(2)), message)
 
         p = re.compile(r'([^\"h]|^)(h?ttps?|ftp)(://[\w:;/.?%\#&=+-~!*@$]+)')
-        correct_scheme = lambda x: 'http' if x == 'ttp' else x
+        correct_scheme = lambda x: 'http' if x == 'ttp' else \
+                                  ('https' if x == 'ttps' else x)
         message = p.sub(
             lambda x: '%(before)s<a href="%(scheme)s%(body)s" target="_blank">'
             '%(raw_scheme)s%(body)s</a>' %
@@ -356,12 +357,20 @@ def get_filenames(input_files):
             continue
         filenames.append(pathname)
 
-    filenames.sort()
+    sort_nicely(filenames)
     return filenames
 
 
+def sort_nicely(l):
+    """ Sort the given list in the way that humans expect.
+    """
+    convert = lambda text: int(text) if text.isdigit() else text
+    alphanum_key = lambda key: [convert(c) for c in re.split('([0-9]+)', key)]
+    return l.sort(key=alphanum_key)
+
+
 def open_file(filename):
-    if os.path.splitext(filename)[1] == ".gz":
+    if filename.endswith(".gz"):
         return gzip.open(filename)
     return open(filename)
 
@@ -388,11 +397,11 @@ def make_index(input_files, output_dir):
     number = 1
     for filename in input_files:
         title = get_title(open_file(filename).readline())
+        path = os.path.basename(filename).replace(".dat", ".html")
+        path = path.decode("utf-8").encode("cp932")
         count = len(open_file(filename).readlines())
         output += (u"　<a href=\"%s\">%s：%s(%s)</a><br>\r\n"
-                   .encode("cp932") %
-                   (os.path.basename(filename).replace(".dat", ".html"),
-                    number, title, count))
+                   .encode("cp932") % (path, number, title, count))
         number += 1
 
     output += "</div>\r\n</body>\r\n</html>\r\n"
@@ -521,6 +530,8 @@ def main():
         if opt in ("-V", "--version"):
             print_version()
             sys.exit()
+        if template_dir == "*text*":
+            index = False
 
     if not len(args):
         print_help()
